/**
 *  Vue BarajaJS
 *  A plugin for spreading items in a card-like fashion.
 *
 *  Copyright 2021-2024, Marc S. Brooks (https://mbrooks.info)
 *  Licensed under the MIT license:
 *  http://www.opensource.org/licenses/mit-license.php
 */

'use strict';

exports.__esModule = true;
exports["default"] = void 0;
var _vue = require("vue");
var _barajaJs = _interopRequireDefault(require("baraja-js"));
require("baraja-js/dist/baraja.min.css");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { "default": e }; }
/**
 * Provides Vue Component wrapper.
 */
var _default2 = exports["default"] = {
  setup: function setup() {
    var elRef = (0, _vue.ref)(null);
    return {
      elRef: elRef
    };
  },
  mounted: function mounted() {
    this.baraja = new _barajaJs["default"](this.$el, this.options);
  },
  data: function data() {
    return {
      baraja: null
    };
  },
  watch: {
    fan: function fan(newVal, oldVal) {
      if (!Object.is(newVal, oldVal)) {
        this.baraja.fan(newVal);
      }
    },
    add: function add(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.add(newVal);
      }
    },
    close: function close(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.close();
      }
    },
    last: function last(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.last();
      }
    },
    next: function next(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.next();
      }
    }
  },
  props: {
    id: {
      "default": 'baraja-js',
      type: String
    },
    options: {
      "default": function _default() {
        return {};
      },
      type: Object
    },
    fan: {
      "default": function _default() {
        return {};
      },
      type: Object
    },
    add: {
      "default": '',
      type: String
    },
    close: {
      "default": false,
      type: Boolean
    },
    last: {
      "default": false,
      type: Boolean
    },
    next: {
      "default": false,
      type: Boolean
    }
  },
  template: "\n    <ul v-bind:id=\"id\" class=\"baraja-container\" ref=\"wrapper\">\n      <slot :child=\"this.$slots.default\" />\n    </ul>\n  "
};
//# sourceMappingURL=vue-baraja.js.map